summaryrefslogtreecommitdiffstats
path: root/Source/cmCableInstantiateCommand.cxx
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
committerBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
commitd0a8794746f6de026f1c69652cd09caf8be9cfab (patch)
tree2143ad59bf1fef6f340dd7fb199f556eadff0ef4 /Source/cmCableInstantiateCommand.cxx
parente5e2a57bfbf1aac2c265e894db82d2b2d5673084 (diff)
downloadCMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.zip
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.gz
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.bz2
ENH: CABIL -> CABLE rename.
Diffstat (limited to 'Source/cmCableInstantiateCommand.cxx')
-rw-r--r--Source/cmCableInstantiateCommand.cxx26
1 files changed, 13 insertions, 13 deletions
diff --git a/Source/cmCableInstantiateCommand.cxx b/Source/cmCableInstantiateCommand.cxx
index b30a1c5..705c313 100644
--- a/Source/cmCableInstantiateCommand.cxx
+++ b/Source/cmCableInstantiateCommand.cxx
@@ -13,14 +13,14 @@
See COPYRIGHT.txt for copyright details.
=========================================================================*/
-#include "cmCabilInstantiateCommand.h"
+#include "cmCableInstantiateCommand.h"
#include "cmCacheManager.h"
-#include "cmCabilDefineSetCommand.h"
+#include "cmCableDefineSetCommand.h"
#include "cmRegularExpression.h"
-// cmCabilInstantiateCommand
-bool cmCabilInstantiateCommand::Invoke(std::vector<std::string>& args)
+// cmCableInstantiateCommand
+bool cmCableInstantiateCommand::Invoke(std::vector<std::string>& args)
{
if(args.size() < 2)
{
@@ -28,8 +28,8 @@ bool cmCabilInstantiateCommand::Invoke(std::vector<std::string>& args)
return false;
}
- // This command instance needs to use the cmCabilData instance.
- this->SetupCabilData();
+ // This command instance needs to use the cmCableData instance.
+ this->SetupCableData();
// The output file must be opened in the output directory.
std::string file = m_Makefile->GetStartOutputDirectory();
@@ -42,7 +42,7 @@ bool cmCabilInstantiateCommand::Invoke(std::vector<std::string>& args)
file += "/" + *arg++;
// Get the OutputFile corresponding to this file name.
- m_OutputFile = m_CabilData->GetOutputFile(file, this);
+ m_OutputFile = m_CableData->GetOutputFile(file, this);
// The rest of the arguments are the elements to be placed in the set.
for(; arg != args.end(); ++arg)
@@ -54,7 +54,7 @@ bool cmCabilInstantiateCommand::Invoke(std::vector<std::string>& args)
}
-void cmCabilInstantiateCommand::FinalPass()
+void cmCableInstantiateCommand::FinalPass()
{
// If this command is the first to reference its output file, write the
// header information.
@@ -70,10 +70,10 @@ void cmCabilInstantiateCommand::FinalPass()
usedCommands.begin();
commandIter != usedCommands.end(); ++commandIter)
{
// If this command is a cmCabilDefineSetCommand, ask it to write its
// configuration code to the output file.
- cmCabilDefineSetCommand* command =
- cmCabilDefineSetCommand::SafeDownCast(*commandIter);
+ cmCableDefineSetCommand* command =
+ cmCableDefineSetCommand::SafeDownCast(*commandIter);
if(command)
{
command->WriteConfiguration(m_OutputFile->GetStream());
@@ -94,9 +94,9 @@ void cmCabilInstantiateCommand::FinalPass()
/**
* Write the CABIL configuration code to define this InstantiationSet.
*/
-void cmCabilInstantiateCommand::WriteConfiguration(std::ostream& os) const
+void cmCableInstantiateCommand::WriteConfiguration(std::ostream& os) const
{
cmRegularExpression needCdataBlock("[&<>]");
@@ -70,10 +70,10 @@ void cmCabilInstantiateCommand::FinalPass()
commandIter != usedCommands.end(); ++commandIter)
{
- // If this command is a cmCabilDefineSetCommand, ask it to write its
+ // If this command is a cmCableDefineSetCommand, ask it to write its
// configuration code to the output file.
@@ -94,9 +94,9 @@ void cmCabilInstantiateCommand::FinalPass()
/**
- * Write the CABIL configuration code to define this InstantiationSet.
+ * Write the CABLE configuration code to define this InstantiationSet.
*/